@@ -12,7 +12,7 @@ use AnyEvent::STOMP::Client;
 
 
 my $cv = AnyEvent->condvar;
-my $stomp_client = new AnyEvent::STOMP::Client()
+my $stomp_client = new AnyEvent::STOMP::Client();
 $stomp_client->connect();
 
 $stomp_client->on_connected(
