@@ -12,7 +12,7 @@ use AnyEvent::Handle;
 use List::Util 'max';
 
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 
 my $EOL = chr(10);
@@ -95,7 +95,7 @@ sub connect {
         on_read => sub {
             $self->read_frame;
         },
-        $self->{tls_hash},
+        %{$self->{tls_hash}},
     );
 }
 
